From 7d4610630b707458be1cbdfd229904f00a5718a8 Mon Sep 17 00:00:00 2001
From: fantu <fantu@ispconfig3>
Date: Tue, 06 Jan 2009 08:38:51 -0500
Subject: [PATCH] remove other duplicates
---
interface/web/sites/web_domain_list.php | 21 +++++++++++----------
1 files changed, 11 insertions(+), 10 deletions(-)
diff --git a/interface/web/sites/web_domain_list.php b/interface/web/sites/web_domain_list.php
index edc7e7f..da46e76 100644
--- a/interface/web/sites/web_domain_list.php
+++ b/interface/web/sites/web_domain_list.php
@@ -41,18 +41,19 @@
* End Form configuration
******************************************/
-// Checking module permissions
-if(!stristr($_SESSION["s"]["user"]["modules"],'sites')) {
- header("Location: ../index.php");
- exit;
+//* Check permissions for module
+$app->auth->check_module_permissions('sites');
+
+$app->load('listform_actions');
+
+
+class list_action extends listform_actions {
+
}
-$app->uses('listform_actions');
-
-// Limit the results to alias domains
-// $app->listform_actions->SQLExtWhere = "type = 'local'";
-
-$app->listform_actions->onLoad();
+$list = new list_action;
+$list->SQLExtWhere = "type = 'vhost'";
+$list->onLoad();
?>
\ No newline at end of file
--
Gitblit v1.9.1